Overview
========

.. role:: mod(emphasis)
.. role:: term(emphasis)

This package provides a simple framework to integrate code with
templates and resources.

See full documentation at:
http://packages.python.org/pyramid_skins/.

About
-----

The package is written and maintained by `Malthe Borch
<mailto:mborch@gmail.com>`_ and `Stefan Eletzhofer
<stefan.eletzhofer@inquant.de>`_. Available *as is* under the BSD
license.

To contribute or get support for this package, please visit the
``#pyramid`` channel on Freenode IRC or write to the `pylons
mailinglist <pylons-discuss@googlegroups.org>`_.
